# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse
from django.http import HttpResponse
from django.shortcuts import render_to_response
from django.template import RequestContext

from forms import FormMunicipio
from models import Municipio


def base_url_js(request):
    return HttpResponse(u"var __municipios_base_url__ = '%s';" % reverse('municipios-base-url'))


def municipios_ajax(request, uf):
    municipio_list = Municipio.objects.filter(uf=uf).order_by('nome')

    return render_to_response("municipios/municipios_options.html",
                              {"municipio_list": municipio_list},
                              context_instance=RequestContext(request))


def teste(request):
    form = FormMunicipio(request.GET or None)
    return render_to_response('municipios/teste.html',
                              {'form': form},
                              context_instance=RequestContext(request),)



# -*- coding: utf-8 -*-
from django import forms

from widgets import SelectMunicipioWidget


class FormMunicipio(forms.Form):
    municipio = forms.IntegerField(label=u"UF - Município", widget=SelectMunicipioWidget, required=False)



try:
    from django.conf.urls import patterns, url
except:
    from django.conf.urls.defaults import patterns, url


urlpatterns = patterns(
    'municipios.views',
    url(r'^$', 'base_url_js', name='municipios-base-url'),
    url(r'^base_url.js$', 'base_url_js', name='municipios-base-url-js'),
    url(r'^ajax/municipios/(?P<uf>\w\w)/$', 'municipios_ajax', name='municipios-ajax'),
    url(r'^teste/', 'teste', name='municipios-teste'),
)



# -*- coding: utf-8 -*-
from django.forms.widgets import Select, Widget

from django.template import Context
from django.template.loader import get_template

from django.utils.safestring import mark_safe

try:
    from django.core.urlresolvers import reverse_lazy
    HAS_REVERSE_LAZY = True
except ImportError:
    HAS_REVERSE_LAZY = False

from municipios.models import Municipio, UF


class SelectMunicipioWidget(Widget):
    """
    Widget to render a <select> with the UFs (Brazillian states)
    and a <select> with the actual Municipio depending on the state
    selected
    """
    def render(self, name, value, attrs=None):
        if value is None:
            value = ''
        attrs = attrs or {}
        if attrs:
            self.attrs.update(attrs)

        output = []
        uf_val = ''
        uf_choices = [('', '--')]+[(uf.pk, uf.uf) for uf in UF.objects.order_by('uf')]
        uf_select = Select(choices=uf_choices)
        municipio_select = Select(choices=(('', '--'),))

        if value:
            try:
                municipio = Municipio.objects.get(pk=value)
                uf_val = municipio.uf.pk
                mun_choices = [(m.pk, m.nome) for m in Municipio.objects.filter(uf=uf_val).order_by('nome')]
                municipio_select = Select(choices=[('', '- Selecione -')]+mun_choices)
            except Municipio.DoesNotExist:
                pass
        uf_attrs = self.attrs.copy()
        uf_attrs.update({"id": '%s_uf' % name, "onchange": "changeUF(this);"})
        select_html = uf_select.render('%s_uf' % name, uf_val, attrs=uf_attrs)
        required = False
        if 'class' in self.attrs:
            required = self.attrs['class']
        #output.append(u'<div class="field"><label%s>UF</label><br />%s</div>' % (required and ' class="required"' or '', select_html))
        template_uf = get_template('municipios/uf_field.html')
        context_uf = Context({'label_class': required, 'wselect': select_html})
        output.append(template_uf.render(context_uf))

        munic_attrs = self.attrs.copy()
        munic_attrs['style'] = "width:250px;"
        select_html = municipio_select.render(name, value, munic_attrs)
        #output.append(u'<div class="field"><label%s>Município</label><br />%s</div>' % (required and ' class="required"' or '', select_html))
        template_mun = get_template('municipios/municipio_field.html')
        context_mun = Context({'label_class': required, 'wselect': select_html})
        output.append(template_mun.render(context_mun))

        return mark_safe(u'\n'.join(output))

    class Media:
        if HAS_REVERSE_LAZY:
            base_url_js = reverse_lazy('municipios-base-url-js')
        else:
            base_url_js = '/municipios_app/base_url.js'
        js = (base_url_js, 'municipios/js/municipio.js',)



# -*- coding: utf-8 -*-
#!/usr/bin/env python

import os
import sys

import municipios

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = municipios.__version__

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    print("You probably want to also tag the version now:")
    print("  git tag -a %s -m 'version %s'" % (version, version))
    print("  git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='django-municipios',
    version=version,
    description="""Aplicação plugável Django com modelos e widgets para os Municípios Brasileiros""",
    long_description=readme + '\n\n' + history,
    author='ZNC Sistemas',
    author_email='contato@znc.com.br',
    url='https://github.com/znc-sistemas/django-municipios',
    packages=[
        'municipios',
    ],
    include_package_data=True,
    install_requires=[
    ],
    license="MIT",
    zip_safe=False,
    keywords='django-municipios',
    classifiers=[
        'Framework :: Django',
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: JavaScript',
        'Topic :: Utilities',
        'Natural Language :: Portuguese (Brazilian)'
#        'Programming Language :: Python :: 2',
#        'Programming Language :: Python :: 2.6',
#        'Programming Language :: Python :: 2.7',
#        'Programming Language :: Python :: 3',
#        'Programming Language :: Python :: 3.3',
    ],
)
